@@ -1,4 +1,5 @@
 from django.conf import settings
+from django.contrib.postgres.indexes import GinIndex
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from django_quill.fields import QuillField
@@ -154,12 +155,10 @@ class Message(models.Model):
     title = models.CharField(
         max_length=64, null=True, blank=True, verbose_name=_("Title")
     )
-    mark = models.CharField(
-        max_length=64,
+    mark = models.JSONField(
         verbose_name=_("Message Mark"),
         null=True,
         blank=True,
-        db_index=True,
     )
     msg_type = models.CharField(
         max_length=64, verbose_name=_("Message Type"), db_index=True
@@ -182,9 +181,22 @@ class Message(models.Model):
 
     objects = models.Manager()
 
-    def __str__(self):
-        return str(self.title)
-
     class Meta:
         verbose_name = _("Message")
         db_table = "message"
+        indexes = [
+            GinIndex(
+                fields=["mark"],
+                name="mark_gin_index",
+            ),
+        ]
+
+    def __str__(self):
+        return str(self.title)
+
+    def save(self, **kwargs):
+        if self.template:
+            self.content = None
+
+        super().save(**kwargs)
+
